@@ -1,6 +1,6 @@
 use core::mem::MaybeUninit;
 use core::ptr;
-use core::sync::atomic::{AtomicBool, AtomicUsize, Ordering};
+use core::sync::atomic::{AtomicUsize, Ordering};
 
 pub struct Sender<'a, T, const N: usize>
 where
@@ -50,8 +50,8 @@ where
     head: AtomicUsize,
     //Tail always points to the first element
     tail: AtomicUsize,
-    has_sender: AtomicBool,
-    has_receiver: AtomicBool,
+    has_sender: bool,
+    has_receiver: bool,
 }
 impl<T, const N: usize> Spsc<T, N>
 where
@@ -63,30 +63,21 @@ where
             buf: MaybeUninit::uninit(),
             head: AtomicUsize::new(0),
             tail: AtomicUsize::new(0),
-            has_sender: AtomicBool::new(true),
-            has_receiver: AtomicBool::new(true),
+            has_sender: true,
+            has_receiver: true,
         }
     }
-    pub fn channel(&self) -> (Option<Sender<T, N>>, Option<Receiver<T, N>>) {
-        let sender = match self.has_sender.compare_exchange_weak(
-            true,
-            false,
-            Ordering::SeqCst,
-            Ordering::Relaxed,
-        ) {
-            Ok(_) => Some(Sender::new(self)),
-            Err(_) => None,
-        };
-        let receiver = match self.has_receiver.compare_exchange_weak(
-            true,
-            false,
-            Ordering::SeqCst,
-            Ordering::Relaxed,
-        ) {
-            Ok(_) => Some(Receiver::new(self)),
-            Err(_) => None,
-        };
-        (sender, receiver)
+    pub const fn channel(&mut self) -> (Sender<T, N>, Receiver<T, N>) {
+        match (self.has_sender, self.has_receiver) {
+            (true, true) => {
+                self.has_sender = false;
+                self.has_receiver = false;
+                (Sender::new(self), Receiver::new(self))
+            }
+            _ => {
+                panic!("spsc had split");
+            }
+        }
     }
     fn ptr(&self) -> *mut T {
         self.buf.as_ptr() as *mut T
